const Mesa = require('vendor/Mesa.js');
const ShopifyGraphql = require('vendor/ShopifyGraphql.js');
const Shopify= require('vendor/Shopify.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {
  script = (payload, context) => {
    let vars = context.steps;
    
    let query = `
      mutation CreateMetaobject($metaobject: MetaobjectCreateInput!) {
        metaobjectCreate(metaobject: $metaobject) {
          metaobject {
            id
            handle
            season: field(key: "season") {
              value
            }
          }
          userErrors {
            field
            message
            code
          }
        }
      }
    `;

    let now = new Date();

    const r = ShopifyGraphql.send(query, {
      "metaobject": {
        "type": "price_point_in_time",
        "capabilities": {
          "publishable": {
            "status": "ACTIVE"
          }
        },
        "fields": [
          {
            "key": "date",
            "value": now.toISOString(),
          },
          {
            "key": "price",
            "value": JSON.stringify({
              "amount": vars.shopify.variants[0].price,
              "currency_code": "USD",
            }),
          }
        ]
      }
    }, {}, 'admin/api/2023-10/graphql.json');

    if (r.data.metaobjectCreate.userErrors.length) {
      throw new Error(JSON.stringify(r.data.metaobjectCreate.userErrors));
    }

    Mesa.output.next({"price_point": r.data.metaobjectCreate.metaobject});
  }
}
